from typing import (
    Iterator,
    List,
    Tuple,
    Union,
)

def _get_column_letter(col_idx: int) -> str: ...
def absolute_coordinate(coord_string: str) -> str: ...
def cols_from_range(range_string: str) -> Iterator[Tuple[str, str, str, str]]: ...
def column_index_from_string(str_col: str) -> int: ...
def coordinate_from_string(coord_string: str) -> Tuple[str, int]: ...
def coordinate_to_tuple(coordinate: str) -> Tuple[int, int]: ...
def get_column_interval(start: str, end: Union[str, int]) -> List[str]: ...
def get_column_letter(idx: int) -> str: ...
def quote_sheetname(sheetname: str) -> str: ...
def range_boundaries(
    range_string: str,
) -> Union[
    Tuple[None, int, None, int], Tuple[int, int, int, int], Tuple[int, None, int, None]
]: ...
def range_to_tuple(range_string: str) -> Tuple[str, Tuple[int, int, int, int]]: ...
def rows_from_range(
    range_string: str,
) -> Iterator[Union[Tuple[str], Tuple[str, str, str, str]]]: ...
